@@ -13,6 +13,8 @@
 #' @param host The IPv4 address that the application should listen on. 
 #' Defaults to the shiny.host option, if set, or "127.0.0.1" if not.
 #' 
+#' @param maxUploadSize is a integer. The max upload file size argument. Default value is 200 (megabyte)
+#' 
 #' @examples
 #' 
 #' #biblioshiny()
@@ -20,7 +22,8 @@
 #' 
 #' @export
 
-biblioshiny <- function(host = "127.0.0.1", port = NULL, launch.browser = TRUE){
+biblioshiny <- function(host = "127.0.0.1", port = NULL, launch.browser = TRUE, maxUploadSize=200){
   
+  shinyOptions(maxUploadSize = maxUploadSize)
   runApp(system.file("biblioshiny",package="bibliometrix"),launch.browser = launch.browser, port = port, host = getOption("shiny.host", host))
 }
