@@ -16,6 +16,8 @@
 #' \code{\link{biblioNetwork}} or \code{\link{cocMatrix}}.
 #' @param n is an integer. It indicates the number of terms to include in the analysis.
 #' @param minfreq is a integer. It indicates the minimum frequency (per thousand) of a cluster. It is a number in the range (0,1000).
+#' @param ngrams is an integer between 1 and 4. It indicates the type of n-gram to extract from texts. 
+#' An n-gram is a contiguous sequence of n terms. The function can extract n-grams composed by 1, 2, 3 or 4 terms. Default value is \code{ngrams=1}.
 #' @param stemming is logical. If it is TRUE the word (from titles or abstracts) will be stemmed (using the Porter's algorithm).
 #' @param size is numerical. It indicates del size of the cluster circles and is a number in the range (0.01,1).
 #' @param n.labels is integer. It indicates how many labels associate to each cluster. Default is \code{n.labels = 1}.
@@ -41,7 +43,7 @@
 #'
 #' @export
 
-thematicMap <- function(M, field="ID", n=250, minfreq=5, stemming=FALSE, size=0.5, n.labels=1, repel=TRUE){
+thematicMap <- function(M, field="ID", n=250, minfreq=5, ngrams=1, stemming=FALSE, size=0.5, n.labels=1, repel=TRUE){
   
   minfreq <- max(2,floor(minfreq*nrow(M)/1000))
   
@@ -56,13 +58,13 @@ thematicMap <- function(M, field="ID", n=250, minfreq=5, stemming=FALSE, size=0.
          },
          TI={
            #if(!("TI_TM" %in% names(values$M))){values$M=termExtraction(values$M,Field="TI",verbose=FALSE, stemming = input$stemming)}
-           M=termExtraction(M,Field="TI",verbose=FALSE, stemming = stemming)
+           M=termExtraction(M,Field="TI", ngrams=ngrams, verbose=FALSE, stemming = stemming)
            NetMatrix <- biblioNetwork(M, analysis = "co-occurrences", network = "titles", n = n, sep = ";")
            
          },
          AB={
            #if(!("AB_TM" %in% names(values$M))){values$M=termExtraction(values$M,Field="AB",verbose=FALSE, stemming = input$stemming)}
-           M=termExtraction(M,Field="AB",verbose=FALSE, stemming = stemming)
+           M=termExtraction(M,Field="AB", ngrams=ngrams, verbose=FALSE, stemming = stemming)
            NetMatrix <- biblioNetwork(M, analysis = "co-occurrences", network = "abstracts", n = n, sep = ";")
            
          })
@@ -176,14 +178,6 @@ thematicMap <- function(M, field="ID", n=250, minfreq=5, stemming=FALSE, size=0.
   df$name_full=L
   ###
   
-  #meandens <- 0
-  #meancentr <- 0
-  #meandens=mean(df$rdensity)
-  #meancentr=mean(df$rcentrality)
-  #df=df[df$freq>=minfreq,]
-  
-  #rangex=max(c(meancentr-min(df$rcentrality),max(df$rcentrality)-meancentr))
-  #rangey=max(c(meandens-min(df$rdensity),max(df$rdensity)-meandens))
   xlimits=c(meancentr-rangex-0.5,meancentr+rangex+0.5)
   ylimits=c(meandens-rangey-0.5,meandens+rangey+0.5)
   
@@ -195,6 +189,11 @@ thematicMap <- function(M, field="ID", n=250, minfreq=5, stemming=FALSE, size=0.
     hjustvar = c(0,0,1,1) ,
     vjustvar = c(0,1.0,0,1))
   
+  data("logo",envir=environment())
+  logo <- grid::rasterGrob(logo,interpolate = TRUE)
+  
+  x <- c(max(df$rcentrality)-0.02-diff(range(df$rcentrality))*0.125, max(df$rcentrality)-0.02)+0.5
+  y <- c(min(df$rdensity),min(df$rdensity)+diff(range(df$rdensity))*0.125)
 
   g=ggplot(df, aes(x=.data$rcentrality, y=.data$rdensity, text=c(.data$words))) +
     geom_point(group="NA",aes(size=log(as.numeric(.data$freq))),shape=20,col=adjustcolor(df$color,alpha.f=0.5))     # Use hollow circles
@@ -217,7 +216,8 @@ thematicMap <- function(M, field="ID", n=250, minfreq=5, stemming=FALSE, size=0.
       theme(axis.text.x=element_blank(),
         axis.ticks.x=element_blank(),
         axis.text.y=element_blank(),
-        axis.ticks.y=element_blank())
+        axis.ticks.y=element_blank()
+        ) + annotation_custom(logo, xmin = x[1], xmax = x[2], ymin = y[1], ymax = y[2]) 
 
   names(df_lab)=c("Occurrences", "Words", "Cluster", "Color","Cluster_Label")
   words=df_lab[order(df_lab$Cluster),]
